package com.cn.fdapfe.biz.service;

import java.util.List;
import com.cn.fdapfe.biz.domain.PerformanceEvaluation;

/**
 * 算法性能评估Service接口
 * 
 * @author Allen
 * @date 2025-03-09
 */
public interface IPerformanceEvaluationService 
{
    /**
     * 查询算法性能评估
     * 
     * @param id 算法性能评估主键
     * @return 算法性能评估
     */
    public PerformanceEvaluation selectPerformanceEvaluationById(Long id);

    /**
     * 查询算法性能评估列表
     * 
     * @param performanceEvaluation 算法性能评估
     * @return 算法性能评估集合
     */
    public List<PerformanceEvaluation> selectPerformanceEvaluationList(PerformanceEvaluation performanceEvaluation);

    /**
     * 新增算法性能评估
     * 
     * @param performanceEvaluation 算法性能评估
     * @return 结果
     */
    public int insertPerformanceEvaluation(PerformanceEvaluation performanceEvaluation);

    /**
     * 修改算法性能评估
     * 
     * @param performanceEvaluation 算法性能评估
     * @return 结果
     */
    public int updatePerformanceEvaluation(PerformanceEvaluation performanceEvaluation);

    /**
     * 批量删除算法性能评估
     * 
     * @param ids 需要删除的算法性能评估主键集合
     * @return 结果
     */
    public int deletePerformanceEvaluationByIds(Long[] ids);

    /**
     * 删除算法性能评估信息
     * 
     * @param id 算法性能评估主键
     * @return 结果
     */
    public int deletePerformanceEvaluationById(Long id);

    int run(Long id);

}
